aboutsummaryrefslogtreecommitdiff
path: root/sim/common/sim-reg.c
diff options
context:
space:
mode:
Diffstat (limited to 'sim/common/sim-reg.c')
-rw-r--r--sim/common/sim-reg.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sim/common/sim-reg.c b/sim/common/sim-reg.c
index 3f3dc41..75cfb0a 100644
--- a/sim/common/sim-reg.c
+++ b/sim/common/sim-reg.c
@@ -36,8 +36,8 @@ sim_fetch_register (SIM_DESC sd, int rn, unsigned char *buf, int length)
return (* CPU_REG_FETCH (cpu)) (cpu, rn, buf, length);
}
-/* Generic implementation of sim_fetch_register for simulators using
- CPU_REG_FETCH.
+/* Generic implementation of sim_store_register for simulators using
+ CPU_REG_STORE.
The contents of BUF are in target byte order. */
/* ??? Obviously the interface needs to be extended to handle multiple
cpus. */